@@ -2,9 +2,9 @@
 // gnubiff -- a mail notification program
 // Copyright (c) 2000-2007 Nicolas Rougier, 2004-2007 Robert Sowada
 //
-// This program is free software; you can redistribute it and/or
+// This program is free software: you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of the
+// published by the Free Software Foundation, either version 3 of the
 // License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful, but
@@ -13,14 +13,12 @@
 // General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ========================================================================
 //
 // File          : $RCSfile: ui-applet-systray.cc,v $
-// Revision      : $Revision: 1.2.2.1 $
-// Revision date : $Date: 2007/05/06 17:37:27 $
+// Revision      : $Revision: 1.2.2.3 $
+// Revision date : $Date: 2008/01/12 14:49:45 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -101,14 +99,9 @@ AppletSystray::show (std::string name)
 void 
 AppletSystray::resize (guint width, guint height)
 {
-	// Get image's current size
-	guint ic_width = 0, ic_height = 0;
-	get_image_size ("image", ic_width, ic_height);
-
 	// Do we need to have the image rescaled?
-	if (((ic_width != width) || (ic_height > height))
-		&& ((ic_width > width) || (ic_height != height))) {
-		widget_max_width_ = width;
+	if ((width != widget_max_width_) || (height != widget_max_height_)) {
+ 		widget_max_width_ = width;
 		widget_max_height_ = height;
 		update (); 
 	}
